/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.connector.jdbc.utils;

import org.apache.eventmesh.connector.jdbc.table.catalog.TableId;

public class MysqlUtils {

    /**
     * Private constructor to prevent instantiation from outside the class.
     */
    private MysqlUtils() {

    }

    /**
     * Generates a wrapped name based on the TableId object.
     *
     * @param tableId The TableId object.
     * @return The generated wrapped name.
     */
    public static String wrapper(TableId tableId) {
        return wrapper(tableId.getCatalogName()) + "." + wrapper(tableId.getTableName());
    }

    /**
     * Generates a wrapped name based on the original string.
     *
     * @param original The original string.
     * @return The generated wrapped name.
     */
    public static String wrapper(String original) {
        return "`" + original + "`";
    }

}
